<?php

return [
    /*
    |--------------------------------------------------------------------------
    | Password Reset Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'reset'     => 'ನಿಮ್ಮ ಪಾಸ್ವರ್ಡ್ ಅನ್ನು ಮರುಹೊಂದಿಸಲಾಗಿದೆ!',
    'sent'      => 'ನಿಮ್ಮ ಪಾಸ್ವರ್ಡ್ ಮರುಹೊಂದಿಸುವ ಲಿಂಕ್ ಅನ್ನು ನಾವು ಇ-ಮೇಲ್ ಮಾಡಿದ್ದೇವೆ!',
    'throttled' => 'Please wait before retrying.',
    'token'     => 'ಈ ಪಾಸ್ವರ್ಡ್ ಮರುಹೊಂದಿಸುವ ಟೋಕನ್ ಅಮಾನ್ಯವಾಗಿದೆ.',
    'user'      => 'ಆ ಇ-ಮೇಲ್ ವಿಳಾಸದೊಂದಿಗೆ ನಾವು ಒಬ್ಬ ಬಳಕೆದಾರನನ್ನು ಹುಡುಕಲಾಗಲಿಲ್ಲ.',
];
